jQuery(document).ready(function ($) {

    // POSTING SUBMISSION
    $('#wpsub-post-form').on('submit', function (e) {
        $('#wpsub-alert-message').html('');
        $("#wpsub-recaptcha-error").html('');

        e.preventDefault();
    
        let formData = new FormData(this);        

        // Conditionally validate reCAPTCHA if the site key is available
        if (wpsub_settings.recaptcha_status) {
            const recaptchaResponse = grecaptcha.getResponse();
            if (!recaptchaResponse) {
                $("#wpsub-recaptcha-error").html('Please complete the reCAPTCHA')
                return;
            }            
            formData.append('g-recaptcha-response', recaptchaResponse);
            grecaptcha.reset();
        }

        // Clear previous error messages
        $('.error-message').remove();
    
        $('.wpsub-submit-btn').html('please wait...');
        $.ajax({
            url: wpsub_settings.ajax_url,
            type: 'POST',
            data: formData,
            processData: false,
            contentType: false,
            success: function (response) {         

                if (response.success==true) {     
                    $('#wpsub-post-form')[0].reset();
                    $(".wpsub-select2").select2("val", "");

                    if (wpsub_settings.recaptcha_status) {
                        grecaptcha.reset();
                    }
                    
                    if(response.data.submission_mode=='paid'){
                        window.location = response.data.redirect_url;
                    }

                    if(wpsub_settings.redirect_url) {
                        window.location = wpsub_settings.redirect_url;
                    } else {
                        $('#wpsub-alert-message').html('<div class="alert alert-success" role="alert">'+response.data.message+'</div>');
                    }
                    
                    $('.wpsub-submit-btn').html('Submit Post')
                } else {
                    // Display error messages
                    if (response.data.errors) {

                        for (const field in response.data.errors) {
                            const errorMessage = response.data.errors[field];
                            $(`[name="${field}"]`).after(`<div class="error-message" style="color:red;font-size:12px;">${errorMessage}</div>`);
                        }
                    } else {
                        alert(response.data); // Fallback for other errors
                    }
                    $('.wpsub-submit-btn').html('Submit Post')
                }
            },
            error: function (xhr, status, error) {
                $('#wpsub-alert-message').html('<div class="alert alert-danger" role="alert">An error occurred. Please try again.</div>');
                alert('There was an error. Please check required fields and try again.');
                $('.wpsub-submit-btn').html('Submit Post')
            }
        });
    });

    // Initialize Select2 for the category field
    $('.wpsub-select2').select2({
        placeholder: "Select categories", // Placeholder text
        allowClear: true
    });
    
});

// TAGS DESIGN
if(wpsub_settings.wpsub_tags) {
    document.addEventListener('DOMContentLoaded', function () {
        const tagsInput = document.querySelector('#wpsub-tags');

        // Initialize Tagify
        const tagify = new Tagify(tagsInput, {
            // whitelist: fspTags, // Existing tags passed from the server
            dropdown: {
                maxItems: 10,
                enabled: 0,
                closeOnSelect: false
            }
        });

        // Convert Tagify value to a plain string before submitting
        const form = tagsInput?.closest('form');
        form.addEventListener('submit', function () {
            tagsInput.value = tagify.value.map(tag => tag.value).join(','); // Convert tags to a CSV string
        });
    });
}

const hamburger = document.getElementById("hamburger");
const menu = document.getElementById("menu");

// hamburger.addEventListener("click", () => {
//     menu.classList.toggle("active");
// });