<?php
class WPSUB_Admin {

    public function __construct() {
        add_action( 'admin_menu', [ $this, 'create_admin_menu' ] );
        add_action( 'admin_init', [ $this, 'register_settings' ] );
        add_action( 'admin_init', [ $this, 'wpsub_register_custom_settings' ] );
        add_action('admin_enqueue_scripts', [$this, 'enqueue_assets']);
    }

    public function enqueue_assets() {
        // Enqueue the JavaScript file.
        wp_enqueue_script(
            'wpsub-admin-settings', 
            WPSUB_PLUGIN_URL . '/assets/js/wpsub-admin-settings.js', 
            [], // Dependencies (if any).
            '1.0.0', // Version.
            true // Load in footer.
        );

        // CSS
        wp_enqueue_style('wpsub-admin-css', WPSUB_PLUGIN_URL . '/assets/css/wpsub-admin.css', true, "1.0.2");
    }

    public function create_admin_menu() {
        add_menu_page(
            'Wizweb Post Submission',
            'Wizweb Post Submission',
            'manage_options',
            'wizweb-post-submission',
            [ $this, 'render_settings_page' ],
            'dashicons-welcome-write-blog',
            2
        );

        

        // Submenu: Transactions
        add_submenu_page(
            'wizweb-post-submission',
            'Transactions',
            'Transactions',
            'manage_options',
            'wpsub_transactions',
            [$this, 'render_transactions_page']
        );
    }

    public function register_settings() 
    {
        // Register Google reCAPTCHA keys separately.
        register_setting( 'wpsub_recaptcha_settings_group', 'wpsub_recaptcha_keys', [
            'sanitize_callback' => [ $this, 'sanitize_recaptcha_keys' ],
        ] );

        // Register Email Setup separately.
        register_setting( 'wpsub_emails_settings_group', 'wpsub_emails_setting', [
            'sanitize_callback' => [ $this, 'sanitize_wpsub_emails_setting' ],
        ] );

        // Register Payments Setup separately.
        register_setting( 'wpsub_payments_setting_group', 'wpsub_payments_setting', [
            'sanitize_callback' => [ $this, 'sanitize_wpsub_payments_setting' ],
        ] );
    }

    // Add a sanitize function for reCAPTCHA keys.
    public function sanitize_recaptcha_keys( $keys ) 
    {
        $sanitized_keys = [
            'site_key'      => sanitize_text_field( $keys['site_key'] ?? '' ),
            'secret_key'    => sanitize_text_field( $keys['secret_key'] ?? '' ),
            'status'        => sanitize_text_field( $keys['status'] ?? '' ),
        ];
    
        // Validate the keys and add appropriate success or error messages.
        if ( empty( $sanitized_keys['site_key'] ) || empty( $sanitized_keys['secret_key'] ) ) {
            add_settings_error(
                'wpsub_recaptcha_settings_group', // Settings group
                'recaptcha_keys_missing',       // Error code
                'Both Site Key and Secret Key are required for reCAPTCHA to function.', // Message
                'error'                         // Type: error
            );
        } else {
            add_settings_error(
                'wpsub_recaptcha_settings_group', // Settings group
                'recaptcha_keys_updated',       // Error code
                'reCAPTCHA keys updated successfully.', // Message
                'success'                       // Type: success
            );
        }
        return $sanitized_keys;
    }  

    public function wpsub_register_custom_settings() {
        register_setting(
            'wpsub_settings_group',
            'wpsub_default_post_status',
            array(
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
            )
        ); 
        register_setting(
            'wpsub_settings_group',
            'wpsub_paid_success_message',
            array(
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
            )
        );
        register_setting(
            'wpsub_settings_group',
            'wpsub_free_success_message',
            array(
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
            )
        );
        register_setting(
            'wpsub_settings_group',
            'wpsub_error_message',
            array(
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
            )
        );
        register_setting(
            'wpsub_settings_group',
            'wpsub_redirect_url',
            array(
                'type'              => 'string',
                'sanitize_callback' => 'esc_url_raw',
            )
        );
        register_setting(
            'wpsub_settings_group',
            'wpsub_richtext_editor',
            array(
                'type' => 'string', 
                'sanitize_callback' => "sanitize_text_field",
            )
        );
        register_setting(
            'wpsub_settings_group',
            'wpsub_unique_title',
            array(
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
            )
        );
        register_setting(
            'wpsub_settings_group',
            'wpsub_category_selection_mode',
            array(
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
            )
        );
        register_setting(
            'wpsub_settings_group',
            'wpsub_show_tags',
            array(
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
            )
        );
        register_setting(
            'wpsub_settings_group',
            'wpsub_show_featured_image',
            array(
                'type'              => 'string',
                'sanitize_callback' => 'sanitize_text_field',
            )
        );
    }

    // Add a sanitize function for Form Setup
    public function sanitize_wpsub_form_setting( $data ) 
    {
        $sanitized_data = sanitize_text_field($data); // Sanitize text field
   
        add_settings_error(
            'wpsub_settings_group_e', // Settings group
            'wpsub_settings_form_updated',       // Error code
            'Form setup updated successfully.', // Message
            'success'                       // Type: success
        );
    
        return $sanitized_data;
    }  

    // Add a sanitize function for emails settings
    public function sanitize_wpsub_emails_setting( $data ) 
    {
        $sanitized_email_settings = [
            'from_name'                                 => sanitize_text_field( $data['from_name'] ?? '' ),
            'from_email'                                => sanitize_text_field( $data['from_email'] ?? '' ),
            'notify_admin_signup'                       => sanitize_text_field( $data['notify_admin_signup'] ?? '' ),
            'notify_admin_post_submission'              => sanitize_text_field( $data['notify_admin_post_submission'] ?? '' ),
            'notify_user_post_submission'               => sanitize_text_field( $data['notify_user_post_submission'] ?? '' ),
            'notify_user_signup'                        => sanitize_text_field( $data['notify_user_signup'] ?? '' ),
            
            'new_post_subject_user'                     => sanitize_text_field( $data['new_post_subject_user'] ?? '' ),
            'new_post_content_user'                     => wp_kses_post( $data['new_post_content_user'] ?? '' ),
            
            'new_post_subject_admin'                    => sanitize_text_field( $data['new_post_subject_admin'] ?? '' ),
            'new_post_content_admin'                    => wp_kses_post( $data['new_post_content_admin'] ?? '' ),
            
            'new_signup_subject_user'                   => sanitize_text_field( $data['new_signup_subject_user'] ?? '' ),
            'new_signup_content_user'                   => wp_kses_post( $data['new_signup_content_user'] ?? '' ),
            
            'new_signup_subject_admin'                  => sanitize_text_field( $data['new_signup_subject_admin'] ?? '' ),
            'new_signup_content_admin'                  => wp_kses_post( $data['new_signup_content_admin'] ?? '' ),
            
            'forgot_password_subject_user'              => sanitize_text_field( $data['forgot_password_subject_user'] ?? '' ),
            'forgot_password_content_user'              => wp_kses_post( $data['forgot_password_content_user'] ?? '' ),
            
            'reset_password_subject_user'               => sanitize_text_field( $data['reset_password_subject_user'] ?? '' ),
            'reset_password_content_user'               => wp_kses_post( $data['reset_password_content_user'] ?? '' ),
            
            'payment_successful_subject_user'           => sanitize_text_field( $data['payment_successful_subject_user'] ?? '' ),
            'payment_successful_content_user'           => wp_kses_post( $data['payment_successful_content_user'] ?? '' ),
            
            'article_publish_subject_user'              => sanitize_text_field( $data['article_publish_subject_user'] ?? '' ),
            'article_publish_content_user'              => wp_kses_post( $data['article_publish_content_user'] ?? '' ),
            
            'payment_successful_subject_admin'          => wp_kses_post( $data['payment_successful_subject_admin'] ?? '' ),
            'payment_successful_content_admin'          => wp_kses_post( $data['payment_successful_content_admin'] ?? '' )
        ];
    
        add_settings_error(
            'wpsub_emails_settings_group', // Settings group
            'email_settings_updated',       // Error code
            'Email Settings has been updated successfully.', // Message
            'success'                       // Type: success
        );
    
        return $sanitized_email_settings;
    }  

    // Add a sanitize function for payments settings
    public function sanitize_wpsub_payments_setting( $data ) 
    {
        $sanitized_email_settings = [
            // 'payment_mode'                  => sanitize_text_field( $data['payment_mode'] ?? '' ),
            'price'                         => sanitize_text_field( $data['price'] ?? '' ),
            'paypal_status'                 => sanitize_text_field( $data['paypal_status'] ?? '' ),
            'paypal_client_id'              => sanitize_text_field( $data['paypal_client_id'] ?? '' ),
            'paypal_secret'                 => sanitize_text_field( $data['paypal_secret'] ?? '' )
        ];
    
        add_settings_error(
            'wpsub_payments_setting_group', // Settings group
            'payment_settings_updated',       // Error code
            'Payments setting has been updated successfully.', // Message
            'success'                       // Type: success
        );
    
        return $sanitized_email_settings;
    }  
    
    public function render_settings_page() { ?>
        <div class="wrap">
            <h1>WPS Settings</h1>
            <?php settings_errors('wpsub_recaptcha_settings_group'); ?>
            <?php settings_errors('wpsub_settings_group_e'); ?>
            <?php settings_errors('wpsub_emails_settings_group'); ?>
            <?php settings_errors('wpsub_payments_setting_group'); ?>

            <div class="support-box">
                <h3>We need your support!</h3>
                <p>Please <a href="https://paypal.me/wizweb?country.x=IN&locale.x=en_GB" target="blank">make a donation</a> and/or <a href="https://wordpress.org/plugins/wizweb-post-submission/#reviews" target="_blank">give this plugin a 5-star rating</a>. If you need any help, email us at: <a href="mailto:support@wizwebitsolutions.com">support@wizwebitsolutions.com</a></p>

                <p>If you need a website developed, an app created, or assistance with WordPress themes, plugins, or marketing solutions, feel free to reach out to us. We’re here to help!</p>

                <p>Your generous support enables continued development of this free plugin. Thank you!</p>

            </div>
            
            <h2 class="nav-tab-wrapper">
                <a href="#tab-recaptcha" class="nav-tab nav-tab-active">Google reCAPTCHA</a>
                <a href="#tab-form-setup" class="nav-tab">Forms</a>
                <a href="#tab-page-setup" class="nav-tab">Pages Mapping</a>
                <a href="#tab-email-setup" class="nav-tab">Emails</a>
                <a href="#tab-payments-setup" class="nav-tab">Payments</a>
            </h2>
            <div id="tab-recaptcha" class="tab-content" style="display: block;">
                <?php $this->render_recaptcha_settings(); ?>
            </div>          
            <div id="tab-form-setup" class="tab-content" style="display: none;">
                <?php $this->render_form_setup_settings(); ?>
            </div>
            <div id="tab-page-setup" class="tab-content" style="display: none;">
                <?php $this->render_page_mapping_settings(); ?>
            </div>
            <div id="tab-email-setup" class="tab-content" style="display: none;">
                <?php $this->render_page_email_settings(); ?>
            </div>
            <div id="tab-payments-setup" class="tab-content" style="display: none;">
                <?php $this->render_page_payment_settings(); ?>
            </div>
        </div>
        <?php
    }

    private function render_recaptcha_settings() {
        $recaptcha_keys = get_option( 'wpsub_recaptcha_keys', [] );
        ?>
        <h2>Google reCAPTCHA</h2>
        <p>To enable Google reCaptcha, enter your public and private keys.</p>
        <p>reCaptcha Version : v2 only</p>
        <form method="post" action="options.php">
            <?php settings_fields( 'wpsub_recaptcha_settings_group' ); ?>
    
            <table class="form-table">
                <tr>
                    <th scope="row">Status</th>
                    <td>
                        <input type="checkbox" name="wpsub_recaptcha_keys[status]" value="1" <?php checked(1, $recaptcha_keys['status'], true); ?> />
                        <label for="wpsub_recaptcha_keys[status]">Enable Google reCAPTCHA field on frontend form</label>
                    </td>
                </tr>
                <tr>
                    <th>Site Key</th>
                    <td>
                        <input type="text" name="wpsub_recaptcha_keys[site_key]" value="<?php echo esc_attr( $recaptcha_keys['site_key'] ?? '' ); ?>" class="regular-text">
                    </td>
                </tr>
                <tr>
                    <th>Secret Key</th>
                    <td>
                        <input type="text" name="wpsub_recaptcha_keys[secret_key]" value="<?php echo esc_attr( $recaptcha_keys['secret_key'] ?? '' ); ?>" class="regular-text">
                    </td>
                </tr>
            </table>
    
            <?php submit_button( 'Save reCAPTCHA Keys' ); ?>
        </form>
        <?php
    }

    private function render_form_setup_settings() {
        ?>
        <h2><?php esc_html_e('Form Setup', 'wizweb-post-submission'); ?></h2>
        <p><?php esc_html_e('Use the following shortcode to display the form on any page:', 'wizweb-post-submission'); ?></p>
        <code>[wpsub_post_submission_page]</code>
    
        <form method="post" action="options.php">
            <?php settings_fields('wpsub_settings_group');?>
            
            
            <table class="form-table">
                <tr>
                    <th scope="row"><?php esc_html_e('Post Status', 'wizweb-post-submission'); ?></th>
                    <td>
                        <select name="wpsub_default_post_status">
                            <option value="draft" <?php selected('draft', get_option('wpsub_default_post_status')); ?>><?php esc_html_e('Draft', 'wizweb-post-submission'); ?></option>
                            <option value="pending" <?php selected('pending', get_option('wpsub_default_post_status', 'pending')); ?>><?php esc_html_e('Pending (default)', 'wizweb-post-submission'); ?></option>
                            <option value="publish" <?php selected('publish', get_option('wpsub_default_post_status')); ?>><?php esc_html_e('Publish immediately', 'wizweb-post-submission'); ?></option>
                        </select>
                        <p class="description"><?php esc_html_e('Post Status for submitted posts', 'wizweb-post-submission'); ?></p>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php esc_html_e('Paid Success Message', 'wizweb-post-submission'); ?></th>
                    <td>
                        <input type="text" name="wpsub_paid_success_message" value="<?php echo esc_attr(get_option('wpsub_paid_success_message', 'Your post has been published successfully.')); ?>" class="large-text">
                        <p class="description"><?php esc_html_e('Message displayed after payment successful post submission', 'wizweb-post-submission'); ?></p>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php esc_html_e('Free Success Message', 'wizweb-post-submission'); ?></th>
                    <td>
                        <input type="text" name="wpsub_free_success_message" value="<?php echo esc_attr(get_option('wpsub_free_success_message', 'Post submitted successfully and is awaiting approval.')); ?>" class="large-text">
                        <p class="description"><?php esc_html_e('Message displayed after successful post submission', 'wizweb-post-submission'); ?></p>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php esc_html_e('Error Message', 'wizweb-post-submission'); ?></th>
                    <td>
                        <input type="text" name="wpsub_error_message" value="<?php echo esc_attr(get_option('wpsub_error_message', 'There was an error. Please check required fields and try again.')); ?>" class="large-text">
                        <p class="description"><?php esc_html_e('Error message displayed if post submission fails', 'wizweb-post-submission'); ?></p>
                    </td>
                </tr>
                <!-- <tr>
                    <th scope="row"><?php //esc_html_e('Redirect URL', 'wizweb-post-submission'); ?></th>
                    <td>
                        <input type="url" name="wpsub_redirect_url" value="<?php //echo esc_url(get_option('wpsub_redirect_url')); ?>" class="large-text">
                        <p class="description"><?php //esc_html_e('Enter a URL to redirect users after a successful submission. Leave blank to stay on the same page.', 'wizweb-post-submission'); ?></p>
                    </td>
                </tr> -->
                <tr>
                    <th scope="row"><?php esc_html_e('Rich Text Editor', 'wizweb-post-submission'); ?></th>
                    <td>
                        <input type="checkbox" name="wpsub_richtext_editor" value="1" <?php checked(1, get_option('wpsub_richtext_editor'), true); ?> />
                        <label for="wpsub_richtext_editor"><?php esc_html_e('Enable RTE/Visual Editor for the Post Content field', 'wizweb-post-submission'); ?></label>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php esc_html_e('Unique Titles', 'wizweb-post-submission'); ?></th>
                    <td>
                        <input type="checkbox" name="wpsub_unique_title" value="1" <?php checked(1, get_option('wpsub_unique_title'), true); ?> />
                        <label for="wpsub_unique_title"><?php esc_html_e('Require submitted post titles to be unique (useful for preventing multiple/duplicate posts)', 'wizweb-post-submission'); ?></label>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php esc_html_e('Post Category', 'wizweb-post-submission'); ?></th>
                    <td>
                        <select name="wpsub_category_selection_mode">
                            <option value="single_required" <?php selected('single_required', get_option('wpsub_category_selection_mode')); ?>><?php esc_html_e('Single Selection (Required)', 'wizweb-post-submission'); ?></option>
                            <option value="single_optional" <?php selected('single_optional', get_option('wpsub_category_selection_mode')); ?>><?php esc_html_e('Single Selection (Optional)', 'wizweb-post-submission'); ?></option>
                            <option value="multiple_required" <?php selected('multiple_required', get_option('wpsub_category_selection_mode')); ?>><?php esc_html_e('Multiple Selection (Required)', 'wizweb-post-submission'); ?></option>
                            <option value="multiple_optional" <?php selected('multiple_optional', get_option('wpsub_category_selection_mode')); ?>><?php esc_html_e('Multiple Selection (Optional)', 'wizweb-post-submission'); ?></option>
                            <option value="hide" <?php selected('hide', get_option('wpsub_category_selection_mode', 'hide')); ?>><?php esc_html_e('Disabled this field', 'wizweb-post-submission'); ?></option>
                        </select>
                        <p class="description"><?php esc_html_e('Choose the category selection mode for the frontend form.', 'wizweb-post-submission'); ?></p>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php esc_html_e('Post Tags', 'wizweb-post-submission'); ?></th>
                    <td>
                        <select name="wpsub_show_tags">
                            <option value="show" <?php selected('show', get_option('wpsub_show_tags')); ?>><?php esc_html_e('Enable and require', 'wizweb-post-submission'); ?></option>
                            <option value="optional" <?php selected('optional', get_option('wpsub_show_tags')); ?>><?php esc_html_e('Enable but do not require', 'wizweb-post-submission'); ?></option>
                            <option value="hide" <?php selected('hide', get_option('wpsub_show_tags', 'hide')); ?>><?php esc_html_e('Disable this field', 'wizweb-post-submission'); ?></option>
                        </select>
                        <p class="description"><?php esc_html_e('Choose the tags selection mode for the frontend form.', 'wizweb-post-submission'); ?></p>
                    </td>
                </tr>
                <tr>
                    <th scope="row"><?php esc_html_e('Post Featured Image', 'wizweb-post-submission'); ?></th>
                    <td>
                        <select name="wpsub_show_featured_image">
                            <option value="show" <?php selected('show', get_option('wpsub_show_featured_image')); ?>><?php esc_html_e('Enable and require', 'wizweb-post-submission'); ?></option>
                            <option value="optional" <?php selected('optional', get_option('wpsub_show_featured_image')); ?>><?php esc_html_e('Enable but do not require', 'wizweb-post-submission'); ?></option>
                            <option value="hide" <?php selected('hide', get_option('wpsub_show_featured_image', 'hide')); ?>><?php esc_html_e('Disable this field', 'wizweb-post-submission'); ?></option>
                        </select>
                        <p class="description"><?php esc_html_e('Choose the featured image selection mode for the frontend form.', 'wizweb-post-submission'); ?></p>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
        <?php
    }
    
    private function render_page_mapping_settings() {
        settings_errors('wpsub_captcha_settings');
        ?>
        <h2><?php esc_html_e('Page Mapping', 'wizweb-post-submission'); ?></h2>
        <p><?php esc_html_e('Manage the pages where login, signup, and forgot password shortcodes are displayed.', 'wizweb-post-submission'); ?></p>
        <?php
        settings_fields('wpsub_page_mapping_settings_group'); // Register settings for this section
        $mapped_pages = [
            'wpsub_login_form'              => esc_html__('Login Page', 'wizweb-post-submission'),
            'wpsub_signup_form'             => esc_html__('Signup Page', 'wizweb-post-submission'),
            'wpsub_forgot_password_form'    => esc_html__('Forgot Password Page', 'wizweb-post-submission'),
            'wpsub_reset_password_form'     => esc_html__('Reset Password Page', 'wizweb-post-submission'),
            'wpsub_post_submission_page'    => esc_html__('Post New Article', 'wizweb-post-submission'),
            'wpsub_payment_page'            => esc_html__('Payment Page', 'wizweb-post-submission'),
            'wpsub_user_dashboard'          => esc_html__('User Dashboard', 'wizweb-post-submission'),
            'wpsub_user_articles'           => esc_html__('Article Lists', 'wizweb-post-submission'),
            'wpsub_user_transaction'        => esc_html__('Transactions', 'wizweb-post-submission'),
        ];
        ?>    
        <table class="form-table">
            <?php foreach ($mapped_pages as $option => $label): ?>
                <tr>
                    <th><?php echo esc_html($label); ?></th>
                    <td>
                        <?php
                        // Example of using `wp_dropdown_pages` if needed
                        // wp_dropdown_pages([
                        //     'name'             => esc_attr($option),
                        //     'selected'         => get_option($option),
                        //     'show_option_none' => esc_html__('— Select a Page —', 'wizweb-post-submission'),
                        // ]);
                        ?>
                        <p class="description">
                            <?php
                            // translators: %s is the shortcode to be added to the page
                            printf(
                                esc_html('Add the shortcode %s to the page where you want it to be displayed.', 'wizweb-post-submission'),
                                '<code>' . esc_html('[' . $option . ']') . '</code>'
                            );
                            ?>
                        </p>

                    </td>
                </tr>
            <?php endforeach; ?>
        </table>    
        <?php
    }

    // Payments Settings
    function render_page_payment_settings() {
        $wpsub_payments_setting = get_option( 'wpsub_payments_setting', [] );
        ?>
        <h2>Payment Methods</h2>
        <p>The active payment methods are listed below. You can sort them to control their display on the frontend.</p>
        <form method="post" action="options.php">
            <?php settings_fields('wpsub_payments_setting_group'); ?>
            
            <table class="form-table">

                <!-- <tr>
                    <th>Enable/Disable Payment Mode</th>
                    <td>
                        <label>
                            <input type="checkbox" name="wpsub_payments_setting[payment_mode]" value="1" <?php checked(1, isset($wpsub_payments_setting['payment_mode']) && $wpsub_payments_setting['payment_mode'], true); ?>/> 
                            Enable PayPal Payments
                        </label>
                        <p class="description"><?php esc_html_e('If you enable payments mode, a submission mode dropdown field will appear on the frontend.', 'wizweb-post-submission'); ?></p>
                    </td>
                </tr> -->

                <tr>
                    <th>Price ($ USD)</th>
                    <td>
                        <input type="number" class="regular-text" name="wpsub_payments_setting[price]" value="<?php echo isset($wpsub_payments_setting['price']) && !empty($wpsub_payments_setting['price']) ? esc_attr($wpsub_payments_setting['price']) : "5"; ?>" />
                        <p class="description"><?php esc_html_e('Specify the price per post in USD.', 'wizweb-post-submission'); ?></p>
                    </td>
                </tr>
                <tr>
                    <th>PayPal Enable/Disable</th>
                    <td>
                        <label><input type="checkbox" name="wpsub_payments_setting[paypal_status]" value="1" <?php checked(1, $wpsub_payments_setting['paypal_status'], true); ?> /> Enable PayPal payments</label>
                        <p class="description"><?php esc_html_e('If you enable payments, please enter a valid PayPal Client ID and Secret Key below.', 'wizweb-post-submission'); ?></p>
                    </td>
                </tr>
                <tr>
                    <th>PayPal Client ID</th>
                    <td>
                        <input type="text" class="large-text" name="wpsub_payments_setting[paypal_client_id]" value="<?php echo isset($wpsub_payments_setting['paypal_client_id']) && !empty($wpsub_payments_setting['paypal_client_id']) ? esc_attr($wpsub_payments_setting['paypal_client_id']) : ""; ?>" />
                    </td>
                </tr>
                <tr>
                    <th>PayPal Secret</th>
                    <td>
                        <input type="text" class="large-text" name="wpsub_payments_setting[paypal_secret]" value="<?php echo isset($wpsub_payments_setting['paypal_secret']) && !empty($wpsub_payments_setting['paypal_secret']) ? esc_attr($wpsub_payments_setting['paypal_secret']) : ""; ?>" />
                    </td>
                </tr>
            </table>

            <?php submit_button(); ?>
        </form>

    <?php
    }

    // Transaction
    public function render_transactions_page() {
        global $wpdb;
        $table_name = $wpdb->prefix . 'wpsub_transactions';
        
        // Define the number of records per page
        $per_page = 15;
        
        // Get the current page number (default to 1)
        $paged = isset($_GET['paged']) ? absint($_GET['paged']) : 1;
        
        // Calculate the offset
        $offset = ( $paged - 1 ) * $per_page;
    
        // Get the total number of transactions
        // phpcs:ignore WordPress.DB.DirectDatabaseQuery
        $total_transactions = absint($wpdb->get_var("SELECT COUNT(*) FROM %i", $table_name));
    
        // Get the transactions for the current page
        // phpcs:ignore WordPress.DB.DirectDatabaseQuery
        $transactions = $wpdb->get_results("SELECT * FROM $table_name ORDER BY id DESC LIMIT $offset, $per_page");
    
        echo '<div class="wrap">';
        echo '<h1 class="wp-heading-inline">Transactions</h1>';
        echo '<hr class="wp-header-end">';
    
        // If no transactions found, display a message
        if (empty($transactions)) {
            echo '<p>' . esc_html__('No transactions found.', 'wizweb-post-submission') . '</p>';
            return;
        }
    
        // Start the table
        echo '<table class="wp-list-table widefat fixed striped">';
        echo '<thead>';
        echo '<tr>';
        echo '<th scope="col" class="manage-column">' . esc_html__('User', 'wizweb-post-submission') . '</th>';
        echo '<th scope="col" class="manage-column">' . esc_html__('Post', 'wizweb-post-submission') . '</th>';
        echo '<th scope="col" class="manage-column">' . esc_html__('Amount', 'wizweb-post-submission') . '</th>';
        echo '<th scope="col" class="manage-column">' . esc_html__('Gateway', 'wizweb-post-submission') . '</th>';
        echo '<th scope="col" class="manage-column">' . esc_html__('Status', 'wizweb-post-submission') . '</th>';
        echo '<th scope="col" class="manage-column">' . esc_html__('Date', 'wizweb-post-submission') . '</th>';
        echo '</tr>';
        echo '</thead>';
    
        // Populate the table rows
        echo '<tbody>';
        foreach ($transactions as $transaction) {
            $user = get_userdata($transaction->user_id);
            $user_link = $user ? get_edit_user_link($transaction->user_id) : '#';
            $post_title = get_the_title($transaction->post_id);
            $post_link = get_edit_post_link($transaction->post_id);
    
            echo '<tr>';
            echo '<td><a target="_blank" href="' . esc_url($user_link) . '">' . esc_html($user ? $user->display_name : __('Deleted User', 'wizweb-post-submission')) . '</a></td>';
            echo '<td><a target="_blank" href="' . esc_url($post_link) . '">' . esc_html($post_title ?: __('Deleted Post', 'wizweb-post-submission')) . '</a></td>';
            echo '<td>' . esc_html('$' . number_format($transaction->amount, 2)) . '</td>';
            echo '<td>' . esc_html($transaction->gateway) . '</td>';
            echo '<td>' . esc_html($transaction->status) . '</td>';
            echo '<td>' . esc_html($transaction->created_at) . '</td>';
            echo '</tr>';
        }
        echo '</tbody>';
    
        echo '<tfoot>';
        echo '<tr>';
        echo '<th scope="col" class="manage-column">' . esc_html__('User', 'wizweb-post-submission') . '</th>';
        echo '<th scope="col" class="manage-column">' . esc_html__('Post', 'wizweb-post-submission') . '</th>';
        echo '<th scope="col" class="manage-column">' . esc_html__('Amount', 'wizweb-post-submission') . '</th>';
        echo '<th scope="col" class="manage-column">' . esc_html__('Gateway', 'wizweb-post-submission') . '</th>';
        echo '<th scope="col" class="manage-column">' . esc_html__('Status', 'wizweb-post-submission') . '</th>';
        echo '<th scope="col" class="manage-column">' . esc_html__('Date', 'wizweb-post-submission') . '</th>';
        echo '</tr>';
        echo '</tfoot>';
        echo '</table>';
    
        // Pagination
        $total_pages = ceil($total_transactions / $per_page);
    
        if ($total_pages > 1) {
            $pagination_args = array(
                'base' => esc_url_raw(add_query_arg('paged', '%#%')),
                'format' => '',
                'total' => $total_pages,
                'current' => $paged,
                'show_all' => false,
                'type' => 'plain',
                'end_size' => 1,
                'mid_size' => 2,
            );
    
            echo '<div class="tablenav">';
            echo '<div class="tablenav-pages">';
            echo wp_kses_post(paginate_links($pagination_args)); // Escaping the output
            echo '</div>';
            echo '</div>';
        }
    
        echo '</div>';
    }

    // FOR EMAIL SETUP
    function render_page_email_settings() {
        $wpsub_emails_setting = get_option( 'wpsub_emails_setting', [] );
        ?>
       <h2>Email Notifications</h2>
        <form method="post" action="options.php">
            <?php settings_fields('wpsub_emails_settings_group'); ?>
            
            <table class="form-table">
                <tr>
                    <th>From Name</th>
                    <td><input type="text" class="regular-text" name="wpsub_emails_setting[from_name]" value="<?php echo isset($wpsub_emails_setting['from_name']) && !empty($wpsub_emails_setting['from_name']) ? esc_attr($wpsub_emails_setting['from_name']) : esc_attr(get_bloginfo('name')); ?>" /></td>
                </tr>
                <tr>
                    <th>From Email</th>
                    <td><input type="text" class="regular-text" name="wpsub_emails_setting[from_email]" value="<?php echo isset($wpsub_emails_setting['from_email']) && !empty($wpsub_emails_setting['from_email']) ? esc_attr($wpsub_emails_setting['from_email']) : esc_attr(get_bloginfo('admin_email')); ?>" /></td>
                </tr>
                <tr>
                    <th>Notify admin via email when	</th>
                    <td>
                        <label><input type="checkbox" name="wpsub_emails_setting[notify_admin_signup]" value="1" <?php checked(1, $wpsub_emails_setting['notify_admin_signup'], true); ?> />New user signs up</label>
                        <br />
                        <label><input type="checkbox" name="wpsub_emails_setting[notify_admin_post_submission]" value="1" <?php checked(1, $wpsub_emails_setting['notify_admin_post_submission'], true); ?>>A new post is submitted </label>
                    </td>
                </tr>
                <tr>
                    <th>Notify users via email when their</th>
                    <td>
                        <label><input type="checkbox" name="wpsub_emails_setting[notify_user_signup]" value="1" <?php checked(1, $wpsub_emails_setting['notify_user_signup'], true); ?> />Signs up</label>
                        <br />
                        <label><input type="checkbox" name="wpsub_emails_setting[notify_user_post_submission]" value="1" <?php checked(1, $wpsub_emails_setting['notify_user_post_submission'], true); ?>>Post is submitted</label>
                    </td>
                </tr>

                <tr>
                    <th>New Post Email To User</th>
                    <td>
                        <label for="wpsub_new_post_subject_user">Subject</label><br />
                        <input type="text" id="wpsub_new_post_subject_user"  class="regular-text" name="wpsub_emails_setting[new_post_subject_user]" value="<?php echo isset($wpsub_emails_setting['new_post_subject_user']) && !empty($wpsub_emails_setting['new_post_subject_user']) ? esc_attr($wpsub_emails_setting['new_post_subject_user']) : 'New Post Submission'; ?>"/>
                        <?php
                        $admin_signup_content = isset($wpsub_emails_setting['new_post_content_user']) && !empty($wpsub_emails_setting['new_post_content_user']) ? esc_attr($wpsub_emails_setting['new_post_content_user']) : '
                        Hello {wpsub_username},  

    Thank you for submitting a post on our website.  

    Post Title: {wpsub_post_title}  
    Status: {wpsub_post_status} 

    Our team will review your post shortly. Once approved, it will be published on the website. We will notify you when your post goes live.  

    If you have any questions, feel free to reach out to us.  

    Thank you,  
    '.esc_attr(get_bloginfo('name')).' Team 
    ';
                        wp_editor($admin_signup_content, 'new_post_content_user', [
                            'textarea_name' => 'wpsub_emails_setting[new_post_content_user]',
                            'media_buttons' => false,   
                            'editor_height' => 300
                        ]);
                        ?>
                    </td>
                </tr>


                <tr>
                    <th>New Post Email To Admin</th>
                    <td>
                        <label for="wpsub_new_post_subject_admin">Subject</label><br />
                        <input type="text" id="wpsub_new_post_subject_admin"  class="regular-text" name="wpsub_emails_setting[new_post_subject_admin]" value="<?php echo isset($wpsub_emails_setting['new_post_subject_admin']) && !empty($wpsub_emails_setting['new_post_subject_admin']) ? esc_attr($wpsub_emails_setting['new_post_subject_admin']) : 'New Post Submission'; ?>"/>
                        <?php
                        $admin_signup_content = isset($wpsub_emails_setting['new_post_content_admin']) && !empty($wpsub_emails_setting['new_post_content_admin']) ? esc_attr($wpsub_emails_setting['new_post_content_admin']) : '
                        Hello Admin,

    A new post has been submitted on your website and is pending review.  

    Here are the details of the submitted post:  

    Post Title: {wpsub_post_title}  
    Submitted By: {wpsub_username}  
    Post URL: {wpsub_post_url}  

    You can review and publish the post by visiting your dashboard.

    Thank you,  
    '.esc_attr(get_bloginfo('name')).' Team  
    ';
                        wp_editor($admin_signup_content, 'ser_new_post_subject_admin', [
                            'textarea_name' => 'wpsub_emails_setting[new_post_content_admin]',
                            'media_buttons' => false,   
                            'editor_height' => 300
                        ]);
                        ?>
                    </td>
                </tr>

                <!-- FOR SIGNUP -->

                <tr>
                    <th>Signup Send Email to User</th>
                    <td>
                        <label for="wpsub_new_signup_subject_user">Subject</label><br />
                        <input type="text" id="wpsub_new_signup_subject_user"  class="regular-text" name="wpsub_emails_setting[new_signup_subject_user]" value="<?php echo isset($wpsub_emails_setting['new_signup_subject_user']) && !empty($wpsub_emails_setting['new_signup_subject_user']) ? esc_attr($wpsub_emails_setting['new_signup_subject_user']) : 'Welcome to '.esc_attr(get_bloginfo('name')).'!'; ?>"/>
                        <?php
                        $admin_signup_content = isset($wpsub_emails_setting['new_signup_content_user']) && !empty($wpsub_emails_setting['new_signup_content_user']) ? esc_attr($wpsub_emails_setting['new_signup_content_user']) : '
                        Hello {wpsub_name},  

    Welcome to '.esc_attr(get_bloginfo('name')).'! We are excited to have you on board.  

    Here are your account details:  

    Username: {wpsub_username}

    If you did not sign up for this account, please contact us immediately.  

    Thank you,  
    '.esc_attr(get_bloginfo('name')).' Team 
    ';
                        wp_editor($admin_signup_content, 'new_signup_content_user', [
                            'textarea_name' => 'wpsub_emails_setting[new_signup_content_user]',
                            'media_buttons' => false,   
                            'editor_height' => 300
                        ]);
                        ?>
                    </td>
                </tr>


                <tr>
                    <th>Signup Send Email to Admin</th>
                    <td>
                        <label for="wpsub_new_signup_subject_admin">Subject</label><br />
                        <input type="text" id="wpsub_new_signup_subject_admin"  class="regular-text" name="wpsub_emails_setting[new_signup_subject_admin]" value="<?php echo isset($wpsub_emails_setting['new_signup_subject_admin']) && !empty($wpsub_emails_setting['new_signup_subject_admin']) ? esc_attr($wpsub_emails_setting['new_signup_subject_admin']) : 'New User Registration'; ?>"/>
                        <?php
                        $admin_signup_content = isset($wpsub_emails_setting['new_signup_content_admin']) && !empty($wpsub_emails_setting['new_signup_content_admin']) ? esc_attr($wpsub_emails_setting['new_signup_content_admin']) : '
                    Hello Admin,

    A new user has registered on your website.  

    Here are the user details:  

    Username: {wpsub_username}  

    You can manage this user by visiting your admin dashboard.

    Thank you,  
    '.esc_attr(get_bloginfo('name')).' Team 
    ';
                        wp_editor($admin_signup_content, 'new_signup_content_admin', [
                            'textarea_name' => 'wpsub_emails_setting[new_signup_content_admin]',
                            'media_buttons' => false,   
                            'editor_height' => 300
                        ]);
                        ?>
                        <pre class="description">HTML is accepted. You can use the following placeholders:<br>{wpsub_name} - The listing owner's display name on the site<br>{wpsub_username} - The listing owner's user name on the site<br>{wpsub_site_name} - Your site name<br>{wpsub_site_url} - Your site url with link<br>{wpsub_post_title} - Post title<br>{wpsub_post_url} - Post url</pre>
                    </td>
                    
                </tr>


                <tr>
                    <th>Forgot Password to User</th>
                    <td>
                        <label for="wpsub_forgot_password_subject_user">Subject</label><br />
                        <input type="text" id="wpsub_forgot_password_subject_user"  class="regular-text" name="wpsub_emails_setting[forgot_password_subject_user]" value="<?php echo isset($wpsub_emails_setting['forgot_password_subject_user']) && !empty($wpsub_emails_setting['forgot_password_subject_user']) ? esc_attr($wpsub_emails_setting['forgot_password_subject_user']) : 'Reset Your Password'; ?>"/>
                        <?php
                        $forgot_password_content_user = isset($wpsub_emails_setting['forgot_password_content_user']) && !empty($wpsub_emails_setting['forgot_password_content_user']) ? esc_attr($wpsub_emails_setting['forgot_password_content_user']) : '
                    Dear {wpsub_name},

    We received a request to reset your password for your '.esc_attr(get_bloginfo('name')).' account. If this was you, please click the link below to create a new password:  

    {wpsub_reset_link}

    If you did not request a password reset, no action is required on your part. Your account is still secure.  

    If you have any questions or need further assistance, feel free to contact our support team at '.get_bloginfo('admin_email').'.

    Thank you,  
    '.esc_attr(get_bloginfo('name')).' Team 
    ';
                        wp_editor($forgot_password_content_user, 'forgot_password_content_user', [
                            'textarea_name' => 'wpsub_emails_setting[forgot_password_content_user]',
                            'media_buttons' => false,   
                            'editor_height' => 300
                        ]);
                        ?>
                        <pre class="description">HTML is accepted. You can use the following placeholders:<br>{wpsub_name} - The listing owner's display name on the site<br>{wpsub_reset_link} - this will be automatically generated.</pre>
                    </td>
                </tr>

                <tr>
                    <th>Reset Password Success to User</th>
                    <td>
                        <label for="wpsub_reset_password_subject_user">Subject</label><br />
                        <input type="text" id="wpsub_reset_password_subject_user"  class="regular-text" name="wpsub_emails_setting[reset_password_subject_user]" value="<?php echo isset($wpsub_emails_setting['reset_password_subject_user']) && !empty($wpsub_emails_setting['reset_password_subject_user']) ? esc_attr($wpsub_emails_setting['reset_password_subject_user']) : 'Your Password Has Been Successfully Changed'; ?>"/>
                        <?php
                        $reset_password_content_user = isset($wpsub_emails_setting['reset_password_content_user']) && !empty($wpsub_emails_setting['reset_password_content_user']) ? esc_attr($wpsub_emails_setting['reset_password_content_user']) : '
                    Dear {wpsub_name},

    We wanted to let you know that your password for your '.esc_attr(get_bloginfo('name')).' account has been successfully changed.

    If you made this change, no further action is required.

    If you did not request this change or suspect any unauthorized access to your account, please reset your password immediately.

    For additional assistance, you can reach out to our support team at '.get_bloginfo('admin_email').'.

    Your security is important to us, and we’re here to help if you need anything!

    Thank you,  
    '.esc_attr(get_bloginfo('name')).' Team 
    ';
                        wp_editor($reset_password_content_user, 'reset_password_content_user', [
                            'textarea_name' => 'wpsub_emails_setting[reset_password_content_user]',
                            'media_buttons' => false,   
                            'editor_height' => 300
                        ]);
                        ?>
                        <pre class="description">HTML is accepted. You can use the following placeholders:<br>{wpsub_name} - The listing owner's display name on the site</pre>
                    </td>
                </tr>

                <tr>
                    <th>After Payment Successful to User</th>
                    <td>
                        <label for="wpsub_payment_successful_subject_user">Subject</label><br />
                        <input type="text" id="wpsub_payment_successful_subject_user"  class="regular-text" name="wpsub_emails_setting[payment_successful_subject_user]" value="<?php echo isset($wpsub_emails_setting['payment_successful_subject_user']) && !empty($wpsub_emails_setting['payment_successful_subject_user']) ? esc_attr($wpsub_emails_setting['payment_successful_subject_user']) : '🎉 Payment Successful!'; ?>"/>
                        <?php
                        $payment_successful_content_user = isset($wpsub_emails_setting['payment_successful_content_user']) && !empty($wpsub_emails_setting['payment_successful_content_user']) ? esc_attr($wpsub_emails_setting['payment_successful_content_user']) : '
                    Dear {wpsub_name},

    Thank you for your payment!

    Here are the details of your transaction:

    Txn ID: {wpsub_txn_id}
    Amount Paid: {wpsub_amount}
    Date: {wpsub_date}

    If you have any questions or need assistance, feel free to reach out to us at '.get_bloginfo('admin_email').'.

    Once again, thank you for choosing '.esc_attr(get_bloginfo('name')).'!

    Thank you,  
    '.esc_attr(get_bloginfo('name')).' Team 
    ';
                        wp_editor($payment_successful_content_user, 'payment_successful_content_user', [
                            'textarea_name' => 'wpsub_emails_setting[payment_successful_content_user]',
                            'media_buttons' => false,   
                            'editor_height' => 400
                        ]);
                        ?>
                        <pre class="description">HTML is accepted. You can use the following placeholders:<br>{wpsub_name} - The listing owner's display name on the site<br>{wpsub_txn_id} - The Show here transaction id<br>{wpsub_amount} - The show here total amount paid user.<br>{wpsub_date} - The show here payment success date.</pre>
                    </td>
                </tr>

                <tr>
                    <th>Article publish to User</th>
                    <td>
                        <label for="wpsub_article_publish_subject_user">Subject</label><br />
                        <input type="text" id="wpsub_article_publish_subject_user"  class="regular-text" name="wpsub_emails_setting[article_publish_subject_user]" value="<?php echo isset($wpsub_emails_setting['article_publish_subject_user']) && !empty($wpsub_emails_setting['article_publish_subject_user']) ? esc_attr($wpsub_emails_setting['article_publish_subject_user']) : '🎉 Your Article is Now Published!'; ?>"/>
                        <?php
                        $article_publish_content_user = isset($wpsub_emails_setting['article_publish_content_user']) && !empty($wpsub_emails_setting['article_publish_content_user']) ? esc_attr($wpsub_emails_setting['article_publish_content_user']) : '
                    Dear {wpsub_name},

    We are excited to let you know that your article has been successfully published on '.esc_attr(get_bloginfo('name')).'! 🎉

    Publication Details:

    Article Title: {wpsub_article_title}
    Publication Date: {wpsub_publish_date}
    Live Link: {wpsub_article_url}

    Your article is now live and available for readers to enjoy. 

    If you notice any issues with your article or need assistance, don’t hesitate to contact us at '.get_bloginfo('admin_email').'.

    Thank you for your valuable contribution to '.esc_attr(get_bloginfo('name')).'. We look forward to more great articles from you!

    Thank you,  
    '.esc_attr(get_bloginfo('name')).' Team 
    ';
                        wp_editor($article_publish_content_user, 'article_publish_content_user', [
                            'textarea_name' => 'wpsub_emails_setting[article_publish_content_user]',
                            'media_buttons' => false,   
                            'editor_height' => 400
                        ]);
                        ?>
                        <pre class="description">HTML is accepted. You can use the following placeholders:<br>{wpsub_name} - The listing owner's display name on the site<br>{wpsub_article_title} - The show here article title<br>{wpsub_publish_date} - The show here article publish date.<br>{wpsub_article_url} - The show here article publish url.</pre>
                    </td>
                </tr>

                <tr>
                    <th>After Payment Successful to Admin</th>
                    <td>
                        <label for="wpsub_payment_successful_subject_admin">Subject</label><br />
                        <input type="text" id="wpsub_payment_successful_subject_admin"  class="regular-text" name="wpsub_emails_setting[payment_successful_subject_admin]" value="<?php echo isset($wpsub_emails_setting['payment_successful_subject_admin']) && !empty($wpsub_emails_setting['payment_successful_subject_admin']) ? esc_attr($wpsub_emails_setting['payment_successful_subject_admin']) : '🚨 New Article Submission with Successful Payment'; ?>"/>
                        <?php
                        $payment_successful_content_admin = isset($wpsub_emails_setting['payment_successful_content_admin']) && !empty($wpsub_emails_setting['payment_successful_content_admin']) ? esc_attr($wpsub_emails_setting['payment_successful_content_admin']) : '
                    Dear Admin,

    A new article has been submitted and the payment was completed successfully. Here are the details:

    Submission Details:

    User Name: {wpsub_username}
    Email: {wpsub_email}
    Article Title: {wpsub_article_title}
    Submission Date: {wpsub_publish_date}
    Payment Amount: {wpsub_amount}
    Live Link: {wpsub_article_url}

    Thank you,  
    '.esc_attr(get_bloginfo('name')).' Team 
    ';
                        wp_editor($payment_successful_content_admin, 'payment_successful_content_admin', [
                            'textarea_name' => 'wpsub_emails_setting[payment_successful_content_admin]',
                            'media_buttons' => false,   
                            'editor_height' => 400
                        ]);
                        ?>
                        <pre class="description">HTML is accepted. You can use the following placeholders:<br>{wpsub_name} - The listing owner's display name on the site<br>{wpsub_article_title} - The show here article title<br>{wpsub_publish_date} - The show here article publish date.<br>{wpsub_article_url} - The show here article publish url.</pre>
                    </td>
                </tr>

            </table>

            <?php submit_button(); ?>
        </form>
    <?php
    }
    
    
}
