<?php
class WPSUB_Forgot_Password {

    public function __construct() {
        add_shortcode( 'wpsub_forgot_password_form', [ $this, 'render_forgot_password_form' ] );
        add_action( 'wp_ajax_nopriv_wpsub_forgot_password', [ __CLASS__, 'handle_forgot_password' ] );
        add_action('wp_enqueue_scripts', [$this, 'enqueue_scripts']);
    }

    public function enqueue_scripts() {
        wp_enqueue_script('wpsub-forgot-password-js', WPSUB_PLUGIN_URL . 'assets/js/wpsub-forgot-password.js', ['jquery'], time(), true);
        wp_localize_script('wpsub-forgot-password-js', 'wpsub_forgot_password_obj', [
            'ajax_url' => admin_url('admin-ajax.php'),
            'security' => wp_create_nonce( 'forgot_password_nonce_action' ),
        ]);
    }

    // Render the forgot password form
    public static function render_forgot_password_form() {
        if ( is_user_logged_in() ) {
            return '<p>You are already logged in.</p>';
        }

        ob_start();
        include plugin_dir_path( __FILE__ ) . '../../templates/auth/forgot-password-form.php';
        return ob_get_clean();
    }

    // AJAX handler for forgot password
    public static function handle_forgot_password() 
    {
        // Verify the nonce
        check_ajax_referer( 'forgot_password_nonce_action', 'security' );

        // Get and sanitize the email
        $email = isset( $_POST['email'] ) ? sanitize_email( wp_unslash( $_POST['email'] ) ) : '';

        if ( ! is_email( $email ) ) {
            wp_send_json_error( [ 'message' => 'Please enter a valid email address.' ] );
        }

        // Check if a user with this email exists
        $user = get_user_by( 'email', $email );
        if ( ! $user ) {
            wp_send_json_error( [ 'message' => 'No account found with this email address.' ] );
        }

        // Generate the password reset key
        $reset_key = get_password_reset_key( $user );
        if ( is_wp_error( $reset_key ) ) {
            wp_send_json_error( [ 'message' => 'Unable to generate password reset link. Please try again.' ] );
        }

        $reset_url = add_query_arg(
            ['action' => 'wpsub_reset_password', 'key' => $reset_key, 'login' => rawurlencode($user->user_login)],
            site_url('reset-password')
        );

        wpsub_send_forgot_password_email($user->ID, $reset_url);
        
        wp_send_json_success( [ 'message' => 'Password reset instructions have been sent to your email.'] );
    }
}