<?php
class WPSUB_Reset_Password {

    public function __construct() {
        add_shortcode( 'wpsub_reset_password_form', [ $this, 'render_reset_password_form' ] );
        add_action('admin_post_nopriv_wpsub_reset_password', [ $this,'handle_reset_password']);
        add_action('admin_post_wpsub_reset_password', [ $this, 'handle_reset_password']);
    }

    // Render the forgot password form
    public static function render_reset_password_form() {
        if ( is_user_logged_in() ) {
            return '<p>You are already logged in.</p>';
        }
        
        ob_start();
        include plugin_dir_path( __FILE__ ) . '../../templates/auth/reset-password-form.php';
        return ob_get_clean();
    }

    public static function handle_reset_password() 
    {

        $key      = isset($_POST['key']) ? sanitize_text_field(wp_unslash($_POST['key'])) : '';
        $login    = isset($_POST['login']) ? sanitize_text_field(wp_unslash($_POST['login'])) : '';
        $password = isset($_POST['new_password']) ? sanitize_text_field(wp_unslash($_POST['new_password'])) : '';
        $confirm  = isset($_POST['confirm_password']) ? sanitize_text_field(wp_unslash($_POST['confirm_password'])) : '';

        // Verify the nonce for security
        if (!isset($_POST['nonce']) || 
            !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['nonce'])), 'wpsub_reset_password_nonce')
        ) {
            wp_redirect(add_query_arg([
                'key'   => $key,
                'login' => $login,
                'errors' => urlencode('Invalid form submission. Please try again.'),
            ], site_url('reset-password')));
            exit;
        }

        

        // Check for password mismatch
        if ($password !== $confirm) {
            wp_redirect(add_query_arg([
                'key'   => $key,
                'login' => $login,
                'errors' => urlencode('Passwords do not match. Please try again.'),
            ], site_url('reset-password')));
            exit;
        }

        // Verify reset key
        $user = check_password_reset_key($key, $login);
        if (is_wp_error($user)) {
            wp_redirect(add_query_arg([
                'key'   => $key,
                'login' => $login,
                'errors' => urlencode($user->get_error_message()),
            ], site_url('reset-password')));
            exit;
        }

        // Reset the password
        reset_password($user, $password);

        wpsub_send_reset_password_email($user->ID);

        // Redirect to success page
        wp_redirect(site_url('login'));
        exit;
    }
}