<?php

class WPSUB_Articles {

    public function __construct() {
        add_shortcode('wpsub_user_articles', [$this, 'render_article_lists']);
        add_action('template_redirect', [$this, 'handle_post_deletion']);
    }

    public function render_article_lists() {
        
        if (!is_user_logged_in()) {
            return "<p>You are not logged in. Please log in to continue. <a href=".esc_url( home_url( '/login' ) ).">Login</a></p>";
            exit;
        }

        $user_id = get_current_user_id();

        // Fetch posts authored by the logged-in user
        $args = [
            'author'        => $user_id,
            'post_type'     => 'post',
            'post_status'   => ['publish', 'draft', 'pending'],
            'orderby'       => 'date',
            'order'         => 'DESC',
        ];
        $user_posts = new WP_Query($args);

        $logout_url = wp_logout_url(home_url());

        ob_start();
        include plugin_dir_path(__FILE__) . '../../templates/users/articles.php';
        wp_reset_postdata();
        return ob_get_clean();
    }

    public function handle_post_deletion() {
        // Check if required query parameters are set
        if (!isset($_GET['wpsub_delete_post'], $_GET['wpsub_nonce'])) {
            return;
        }
    
        // Sanitize and unslash the input values
        $post_id = intval($_GET['wpsub_delete_post']);
        $nonce = sanitize_text_field(wp_unslash($_GET['wpsub_nonce']));
    
        // Verify the nonce
        if (!wp_verify_nonce($nonce, 'wpsub_delete_post_' . $post_id)) {
            wp_die('Security check failed.');
        }
    
        // Get the post and verify the current user's permissions
        $post = get_post($post_id);
        if (!$post || $post->post_author != get_current_user_id()) {
            wp_die('You do not have permission to delete this post.');
        }
    
        // Delete the post
        wp_delete_post($post_id, true); // Force delete
    
        // Redirect with a success message
        wp_redirect(add_query_arg('wpsub_message', 'deleted', remove_query_arg(['wpsub_delete_post', 'wpsub_nonce'])));
        exit;
    }
    
}

new WPSUB_Articles();
