<?php

$headers = array('Content-Type: text/html; charset=UTF-8');

function wpsub_replace_placeholders($content, $user_id = null, $post_id = null, $reset_link=null) {
    // Default placeholders
    $placeholders = [
        '{wpsub_site_name}' => get_bloginfo('name'),
        '{wpsub_site_url}'  => get_bloginfo('url'),
    ];

    // User-related placeholders
    if ($user_id) {
        $user_info = get_userdata($user_id);
        if ($user_info) {
            $placeholders['{wpsub_name}']     = $user_info->display_name;
            $placeholders['{wpsub_username}'] = $user_info->user_login;
        }
    }

    // Post-related placeholders
    if ($post_id) {
        $post_info = get_post($post_id);
        if ($post_info) {
            $placeholders['{wpsub_post_title}']     = $post_info->post_title;
            $placeholders['{wpsub_post_status}']    = $post_info->post_status;
            $placeholders['{wpsub_post_url}']       = get_permalink($post_id);
        }
    }

    // Forgot Password
    if ($reset_link) {
        if ($reset_link) {
            $placeholders['{wpsub_reset_link}']   = $reset_link;
        }
    }

    // Replace placeholders in the content
    return str_replace(array_keys($placeholders), array_values($placeholders), $content);
}

function wpsub_notify_on_signup($user_id) {
    $wpsub_emails_setting = get_option('wpsub_emails_setting', []);

    $notify_admin   = !empty($wpsub_emails_setting['notify_admin_signup']);
    $notify_user    = !empty($wpsub_emails_setting['notify_user_signup']);

    $from_name      = !empty($wpsub_emails_setting['from_name']) ? esc_attr($wpsub_emails_setting['from_name']) : esc_attr(get_bloginfo('name'));
    $from_email     = !empty($wpsub_emails_setting['from_email']) ? esc_attr($wpsub_emails_setting['from_email']) : esc_attr(get_bloginfo('admin_email'));

    $admin_subject  = !empty($wpsub_emails_setting['new_signup_subject_admin']) ? $wpsub_emails_setting['new_signup_subject_admin'] : 'New User Registration';
    $admin_content  = !empty($wpsub_emails_setting['new_signup_content_admin']) ? $wpsub_emails_setting['new_signup_content_admin'] : '';

    $user_subject   = !empty($wpsub_emails_setting['new_signup_subject_user']) ? $wpsub_emails_setting['new_signup_subject_user'] : 'Welcome to ' . esc_attr(get_bloginfo('name')) . '!';
    $user_content   = !empty($wpsub_emails_setting['new_signup_content_user']) ? $wpsub_emails_setting['new_signup_content_user'] : '';

    // Get admin email
    $admin_email = get_bloginfo('admin_email');

    // Admin Notification
    if ($notify_admin && $admin_email) {
        $admin_email_content = wpsub_replace_placeholders($admin_content, $user_id);
        wp_mail(
            $admin_email,
            $admin_subject,
            $admin_email_content,
            [
                'From: ' . $from_name . ' <' . $from_email . '>',
            ],
            $headers 
        );
    }

    // User Notification
    if ($notify_user) {
        $user_info = get_userdata($user_id);
        if ($user_info && isset($user_info->user_email)) {
            $user_email_content = wpsub_replace_placeholders($user_content, $user_id);
            wp_mail(
                $user_info->user_email,
                $user_subject,
                $user_email_content,
                [
                    'From: ' . $from_name . ' <' . $from_email . '>',
                ],
                $headers 
            );
        }
    }

    return true;
}

function wpsub_notify_on_post_submission($user_id, $post_id) {
    $wpsub_emails_setting = get_option('wpsub_emails_setting', []);

    $notify_admin   = !empty($wpsub_emails_setting['notify_admin_post_submission']);
    $notify_user    = !empty($wpsub_emails_setting['notify_user_post_submission']);

    $from_name      = !empty($wpsub_emails_setting['from_name']) ? esc_attr($wpsub_emails_setting['from_name']) : esc_attr(get_bloginfo('name'));
    $from_email     = !empty($wpsub_emails_setting['from_email']) ? esc_attr($wpsub_emails_setting['from_email']) : esc_attr(get_bloginfo('admin_email'));

    $admin_subject  = !empty($wpsub_emails_setting['new_post_subject_admin']) ? $wpsub_emails_setting['new_post_subject_admin'] : 'New User Registration';
    $admin_content  = !empty($wpsub_emails_setting['new_post_content_admin']) ? $wpsub_emails_setting['new_post_content_admin'] : '';

    $user_subject   = !empty($wpsub_emails_setting['new_post_subject_user']) ? $wpsub_emails_setting['new_post_subject_user'] : 'Welcome to ' . esc_attr(get_bloginfo('name')) . '!';
    $user_content   = !empty($wpsub_emails_setting['new_post_content_user']) ? $wpsub_emails_setting['new_post_content_user'] : '';

    // Get admin email
    $admin_email = get_bloginfo('admin_email');

    // Admin Notification
    if ($notify_admin && $admin_email) {
        $admin_email_content = wpsub_replace_placeholders($admin_content, $user_id, $post_id);
        wp_mail(
            $admin_email,
            $admin_subject,
            $admin_email_content,
            [
                'From: ' . $from_name . ' <' . $from_email . '>',
            ],
            $headers 
        );
    }

    // User Notification
    if ($notify_user) {
        $user_info = get_userdata($user_id);
        if ($user_info && isset($user_info->user_email)) {
            $user_email_content = wpsub_replace_placeholders($user_content, $user_id, $post_id);
            wp_mail(
                $user_info->user_email,
                $user_subject,
                $user_email_content,
                [
                    'From: ' . $from_name . ' <' . $from_email . '>',
                ],
                $headers 
            );
        }
    }

    return true;
}

function wpsub_send_forgot_password_email($user_id, $reset_link) 
{

    $wpsub_emails_setting = get_option('wpsub_emails_setting', []);

    $from_name      = !empty($wpsub_emails_setting['from_name']) ? esc_attr($wpsub_emails_setting['from_name']) : esc_attr(get_bloginfo('name'));
    $from_email     = !empty($wpsub_emails_setting['from_email']) ? esc_attr($wpsub_emails_setting['from_email']) : esc_attr(get_bloginfo('admin_email'));

    $user_subject   = $wpsub_emails_setting['forgot_password_subject_user'];
    $user_content   = $wpsub_emails_setting['forgot_password_content_user'];

    // User Notification
    $user_info = get_userdata($user_id);
    if ($user_info && isset($user_info->user_email)) 
    {
        $user_email_content = wpsub_replace_placeholders($user_content, $user_id, "", $reset_link);
        wp_mail(
            $user_info->user_email,
            $user_subject,
            $user_email_content,
            [
                'From: ' . $from_name . ' <' . $from_email . '>',
            ],
            $headers 
        );
    }

    return true;
}

function wpsub_send_reset_password_email($user_id) 
{
    $wpsub_emails_setting = get_option('wpsub_emails_setting', []);

    $from_name      = !empty($wpsub_emails_setting['from_name']) ? esc_attr($wpsub_emails_setting['from_name']) : esc_attr(get_bloginfo('name'));
    $from_email     = !empty($wpsub_emails_setting['from_email']) ? esc_attr($wpsub_emails_setting['from_email']) : esc_attr(get_bloginfo('admin_email'));

    $user_subject   = $wpsub_emails_setting['reset_password_subject_user'];
    $user_content   = $wpsub_emails_setting['reset_password_content_user'];

    // User Notification
    $user_info = get_userdata($user_id);
    if ($user_info && isset($user_info->user_email)) 
    {
        $user_email_content = wpsub_replace_placeholders($user_content, $user_id, "", $reset_link);
        wp_mail(
            $user_info->user_email,
            $user_subject,
            $user_email_content,
            [
                'From: ' . $from_name . ' <' . $from_email . '>',
            ],
            $headers 
        );
    }

    return true;
}


function wpsub_payment_successful_email_to_user($txn_details) 
{

    $user_info = get_userdata($txn_details->user_id);

    $placeholders = [
        '{wpsub_name}'      => $user_info->display_name,
        '{wpsub_txn_id}'    => $txn_details->transaction_id,
        '{wpsub_amount}'    => '$'.$txn_details->amount,
        '{wpsub_date}'      => $txn_details->created_at,
    ];

    $wpsub_emails_setting = get_option('wpsub_emails_setting', []);

    $from_name      = !empty($wpsub_emails_setting['from_name']) ? esc_attr($wpsub_emails_setting['from_name']) : esc_attr(get_bloginfo('name'));
    $from_email     = !empty($wpsub_emails_setting['from_email']) ? esc_attr($wpsub_emails_setting['from_email']) : esc_attr(get_bloginfo('admin_email'));

    $user_subject   = $wpsub_emails_setting['payment_successful_subject_user'];
    $user_content   = $wpsub_emails_setting['payment_successful_content_user'];

    // User Notification
    
    if ($user_info && isset($user_info->user_email)) 
    {
        $user_email_content = str_replace(array_keys($placeholders), array_values($placeholders), $user_content);;
        wp_mail(
            $user_info->user_email,
            $user_subject,
            $user_email_content,
            [
                'From: ' . $from_name . ' <' . $from_email . '>',
            ],
            $headers 
        );
    }

    return true;
}

function wpsub_payment_successful_email_to_admin($txn_details) 
{
    $user_info = get_userdata($txn_details->user_id);
    $post_info = get_post($txn_details->post_id);

    $placeholders = [
        '{wpsub_username}'          => $user_info->user_login,
        '{wpsub_email}'             => $user_info->user_email,
        '{wpsub_article_title}'     => $post_info->post_title,
        '{wpsub_publish_date}'      => $txn_details->created_at,
        '{wpsub_amount}'            => '$'.$txn_details->amount,
        '{wpsub_article_url}'       => get_permalink($txn_details->post_id),
    ];

    $wpsub_emails_setting = get_option('wpsub_emails_setting', []);

    $from_name      = !empty($wpsub_emails_setting['from_name']) ? esc_attr($wpsub_emails_setting['from_name']) : esc_attr(get_bloginfo('name'));
    $from_email     = !empty($wpsub_emails_setting['from_email']) ? esc_attr($wpsub_emails_setting['from_email']) : esc_attr(get_bloginfo('admin_email'));

    $admin_subject   = $wpsub_emails_setting['payment_successful_subject_admin'];
    $admin_content   = $wpsub_emails_setting['payment_successful_content_admin'];

    // User Notification

    $admin_email = get_bloginfo('admin_email');

    // Admin Notification
    if ($admin_email) {
        $admin_email_content = str_replace(array_keys($placeholders), array_values($placeholders), $admin_content);
        wp_mail(
            $admin_email,
            $admin_subject,
            $admin_email_content,
            [
                'From: ' . $from_name . ' <' . $from_email . '>',
            ],
            $headers 
        );
    }

    return true;
}

function wpsub_article_publish_email_to_user($txn_details) 
{
    $user_info = get_userdata($txn_details->user_id);
    $post_info = get_post($txn_details->post_id);

    $placeholders = [
        '{wpsub_name}'              => $user_info->display_name,
        '{wpsub_article_title}'     => $post_info->post_title,
        '{wpsub_publish_date}'      => $txn_details->created_at,
        '{wpsub_article_url}'       => get_permalink($txn_details->post_id),
    ];

    $wpsub_emails_setting = get_option('wpsub_emails_setting', []);

    $from_name      = !empty($wpsub_emails_setting['from_name']) ? esc_attr($wpsub_emails_setting['from_name']) : esc_attr(get_bloginfo('name'));
    $from_email     = !empty($wpsub_emails_setting['from_email']) ? esc_attr($wpsub_emails_setting['from_email']) : esc_attr(get_bloginfo('admin_email'));

    $user_subject   = $wpsub_emails_setting['article_publish_subject_user'];
    $user_content   = $wpsub_emails_setting['article_publish_content_user'];

    // User Notification
    
    if ($user_info && isset($user_info->user_email)) 
    {
        $user_email_content = str_replace(array_keys($placeholders), array_values($placeholders), $user_content);;
        wp_mail(
            $user_info->user_email,
            $user_subject,
            $user_email_content,
            [
                'From: ' . $from_name . ' <' . $from_email . '>',
            ],
            $headers 
        );
    }

    return true;
}

?>