<?php
if ( ! defined( 'ABSPATH' ) ) exit;

// Get Google reCAPTCHA site key from admin settings.
$recaptcha_keys         = get_option( 'wpsub_recaptcha_keys', [] );
$recaptcha_status       = $recaptcha_keys['status'] ?? '';
$recaptcha_site_key     = $recaptcha_keys['site_key'] ?? '';
$recaptcha_secret_key   = $recaptcha_keys['secret_key'] ?? '';

// Fetch categories
$categories = get_categories( array(
    'orderby'       => 'name',
    'order'         => 'ASC',
    'hide_empty'    => false
) );

$payments_settings = get_option( 'wpsub_payments_setting', [] );
?>

<form id="wpsub-post-form" method="post"  enctype="multipart/form-data">

    <div class="form-group">
        <label for="wpsub-title">Title</label>
        <input type="text" id="wpsub-title" name="title">
    </div>
    
    <div class="form-group">
        <label for="wpsub-content">Content</label>
        <!-- <textarea id="wpsub-content" name="content"></textarea> -->
        <?php
        if(get_option('wpsub_richtext_editor')) {
            // Add the WordPress editor for the content field
            $content = ''; // Default content (empty)
            $editor_id = 'post_content'; // ID for the editor
            $settings = array(
                'textarea_name' => 'content', // Name of the textarea in form
                'textarea_rows' => 10,             // Number of rows in the editor
                'media_buttons' => false,          // Disable "Add Media" button
                'teeny'         => false,           // Use a simplified version of TinyMCE
                'quicktags'     => false,           // Enable quicktags for basic HTML editing
            );
            wp_editor($content, $editor_id, $settings);
        } else {
            echo '<textarea name="content" rows="5"></textarea>';
        }       
        ?>
    </div>

    <?php 
        if (get_option('wpsub_category_selection_mode') == "multiple_required" || get_option('wpsub_category_selection_mode') == "multiple_optional" || get_option('wpsub_category_selection_mode') == "single_required" || get_option('wpsub_category_selection_mode') == "single_optional") {
                if ( ! empty( $categories ) ) :
                ?>
                <div class="form-group">
                    <label for="category">Select Category</label>

                    <?php if (get_option('wpsub_category_selection_mode') == "multiple_required" || get_option('wpsub_category_selection_mode') == "multiple_optional") {?>
                    <select name="categories[]" id="categories" multiple class="wpsub-select2" >
                        <?php
                            $categories = get_categories(array('hide_empty' => false));
                            foreach ($categories as $category) {
                                echo '<option value="' . esc_attr($category->term_id) . '">' . esc_html($category->name) . '</option>';
                            }
                        ?>
                    </select>
                    <?php } ?>
                    
                    
                    <?php if (get_option('wpsub_category_selection_mode') == "single_required" || get_option('wpsub_category_selection_mode') == "single_optional") {?>
                        <select name="category" id="category">
                            <option value="">Select a category</option>
                            <?php foreach ( $categories as $category ) : ?>
                                <option value="<?php echo esc_attr( $category->term_id ); ?>">
                                    <?php echo esc_html( $category->name ); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    <?php }?>

                </div>
            <?php
            else :
                echo 'No categories available.';
            endif;
        }
    ?>

    <?php  if (get_option('wpsub_show_tags') == "show" || get_option('wpsub_show_tags') == "optional") { ?>
        <div class="form-group">
            <label for="wpsub-tags">Tags</label>
            <input type="text" id="wpsub-tags" name="tags" placeholder="Add tags...">
        </div>
    <?php } ?>

    <?php  if (get_option('wpsub_show_featured_image')  == "show" || get_option('wpsub_show_featured_image') == "optional") { ?>
        <div class="form-group">
            <label for="featured_image">Featured Image</label>
            <input type="file" name="featured_image" id="featured_image" />
        </div>
    <?php } ?>

    <?php if ( $payments_settings['paypal_status'] ): ?>
        <div class="form-group">
            <label for="submission_mode">Select Submission Mode:</label>
            <select name="submission_mode" required>
                <option value="free">Free</option>
                <option value="paid">Paid (Post published instantly after payment)</option>
            </select>
        </div>
    <?php endif; ?>

    <!-- Google reCAPTCHA -->
    <?php if ( $recaptcha_site_key && $recaptcha_status ): ?>
        <div class="form-group">
            <label for="wpsub-tags">Verification</label>
            <div class="g-recaptcha" data-sitekey="<?php echo esc_attr( $recaptcha_site_key ); ?>"></div>
            <p id="wpsub-recaptcha-error"></p>
        </div>
    <?php endif; ?>

    <button type="submit" class="wpsub-submit-btn">Submit Post</button>

    <input type="hidden" name="action" value="submit_post">

    <div id="wpsub-alert-message"></div>
    <?php wp_nonce_field( 'wpsub_nonce', 'security' ); ?>
</form>
