<?php
/**
 * Plugin Name: Wizweb Post Submission
 * Plugin URI: https://www.wizwebitsolutions.com/contact-us
 * Description: A powerful front-end post submission plugin with customizable forms, user dashboards, and PayPal payment integration for post publishing.
 * Tags: directory, classified, Frontend Post Form, user post, form builder
 * Version: 1.0.8
 * Author: Wizweb IT Solutions
 * Author URI: https://www.wizwebitsolutions.com
 * Contributors: Hemant Vishwakarma
 * Text Domain: wizweb-post-submission
 * License: GPL v2 or later
 */

 /*
	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 
	2 of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	with this program. If not, visit: https://www.gnu.org/licenses/
	
	Copyright 2024 Monzilla Media. All rights reserved.
*/


// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

// Define constants for plugin paths.
define( 'WPSUB_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
define( 'WPSUB_PLUGIN_URL', plugin_dir_url( __FILE__ ) );

// Include necessary files.
require_once WPSUB_PLUGIN_DIR . 'includes/admin/class-wpsub-admin.php';
require_once WPSUB_PLUGIN_DIR . 'includes/class-wpsub-recaptcha.php';
require_once WPSUB_PLUGIN_DIR . 'includes/auth/class-wpsub-login.php';
require_once WPSUB_PLUGIN_DIR . 'includes/auth/class-wpsub-signup.php';
require_once WPSUB_PLUGIN_DIR . 'includes/auth/class-wpsub-forgot-password.php';
require_once WPSUB_PLUGIN_DIR . 'includes/auth/class-wpsub-reset-password.php';
require_once WPSUB_PLUGIN_DIR . 'includes/auth/class-wpsub-redirect.php';

// Post Submission
require_once WPSUB_PLUGIN_DIR . 'includes/class-wpsub-post-submission.php';
require_once WPSUB_PLUGIN_DIR . 'includes/class-wpsub-payment-handler.php';

// Users 
require_once WPSUB_PLUGIN_DIR . 'includes/users/class-wpsub-dashboard.php';
require_once WPSUB_PLUGIN_DIR . 'includes/users/class-wpsub-transaction.php';
require_once WPSUB_PLUGIN_DIR . 'includes/users/class-wpsub-articles.php';

// Lib
require_once WPSUB_PLUGIN_DIR . 'lib/wpsub-email-handler.php';


// Initialize plugin.
class WizwebPostSubmission {
    
    public function __construct() {
        new WPSUB_Admin();
        new WPSUB_Post_Submission();
        new WPSUB_Payment_Handler();
        new WPSUB_Recaptcha();
        new WPSUB_Login();
        new WPSUB_Signup();
        new WPSUB_Forgot_Password();
        new WPSUB_Reset_Password();
        new WPSUB_Redirect();
        new WPSUB_Dashboard();
        new WPSUB_Transaction();
        new WPSUB_Articles();
        register_activation_hook( __FILE__, [ $this, 'activate' ] );
        register_uninstall_hook( __FILE__, [ 'WizwebPostSubmission', 'uninstall' ] );
    }

    public function activate() {

        // Create Pages
        $pages = [
            'Login'             => '[wpsub_login_form]',
            'Signup'            => '[wpsub_signup_form]',
            'Forgot Password'   => '[wpsub_forgot_password_form]',
            'Reset Password'    => '[wpsub_reset_password_form]',
            'Post New Article'  => '[wpsub_post_submission_page]',
            'Payments'          => '[wpsub_payment_page]',
            'Dashboard'         => '[wpsub_user_dashboard]',
            'Article Lists'     => '[wpsub_user_articles]',
            'Transactions'      => '[wpsub_user_transaction]',
        ];    
        foreach ($pages as $title => $shortcode) {
            // Use WP_Query to check if a page with the same title exists
            $query = new WP_Query([
                'post_type'   => 'page',
                'post_status' => 'publish',
                'title'       => $title,
            ]);
    
            // If no page with the title exists, create a new one
            if (!$query->have_posts()) {
                wp_insert_post([
                    'post_title'   => $title,
                    'post_content' => $shortcode,
                    'post_status'  => 'publish',
                    'post_type'    => 'page',
                ]);
            }    
            // Always reset the global post data after a query
            wp_reset_postdata();
        }

        // Setup Transaction Table
        global $wpdb;
        $table_name         = $wpdb->prefix . 'wpsub_transactions';
        $charset_collate    = $wpdb->get_charset_collate();

        $sql = "CREATE TABLE $table_name (
            id BIGINT(20) UNSIGNED AUTO_INCREMENT PRIMARY KEY,
            user_id BIGINT(20) UNSIGNED NOT NULL,
            post_id BIGINT(20) UNSIGNED NOT NULL,
            transaction_id VARCHAR(255) NOT NULL,
            gateway VARCHAR(255) NOT NULL,
            amount DECIMAL(10,2) NOT NULL,
            status VARCHAR(20) NOT NULL,
            created_at DATETIME DEFAULT CURRENT_TIMESTAMP,
            FOREIGN KEY (user_id) REFERENCES {$wpdb->prefix}users(ID)
        ) $charset_collate;";

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }

    public static function uninstall() {
        delete_option( 'wpsub_recaptcha_keys' );
        delete_option( 'wpsub_show_featured_image' );
        delete_option( 'wpsub_show_tags' );
        delete_option( 'wpsub_category_selection_mode' );
        delete_option( 'wpsub_unique_title' );
        delete_option( 'wpsub_richtext_editor' );
        delete_option( 'wpsub_redirect_url' );
        delete_option( 'wpsub_error_message' );
        delete_option( 'wpsub_free_success_message' );
        delete_option( 'wpsub_paid_success_message' );
        delete_option( 'wpsub_default_post_status' );
        delete_option( 'wpsub_emails_setting' );
        delete_option( 'wpsub_payments_setting' );     
    }
}

new WizwebPostSubmission();
